@@ -1,16 +1,17 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+
+from .common import *
+import json
+import decimal
+
+
 __author__ = 'James Iter'
 __date__ = '15/4/27'
 __contact__ = 'james.iter.cn@gmail.com'
 __copyright__ = '(c) 2015 by James Iter.'
 
-import decimal
-import json
-
-from common import *
-
 
 class Convert(object):
 
@@ -29,9 +30,9 @@ class Convert(object):
                     j_sql[col.name] = str(getattr(sql_obj, col.name))
                 else:
                     j_sql[col.name] = getattr(sql_obj, col.name)
-        except Exception, e:
+        except Exception as e:
             result['state'] = Common.exchange_state(50003)
-            result['state']['sub']['detail'] = e.message
+            result['state']['sub']['detail'] = e.__str__()
             raise ji.JITError(json.dumps(result))
 
         result['j_sql'] = j_sql
